@@ -12,9 +12,7 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
- *
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "config.h"
@@ -200,7 +198,7 @@ ephy_gui_check_location_writable (GtkWidget *parent,
 		{
 			dialog = gtk_message_dialog_new (
 					parent ? GTK_WINDOW(parent) : NULL,
-					GTK_DIALOG_DESTROY_WITH_PARENT,
+					GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
 					GTK_MESSAGE_ERROR,
 					GTK_BUTTONS_CLOSE,
 					_("Directory “%s” is not writable"), path);
@@ -236,7 +234,7 @@ ephy_gui_check_location_writable (GtkWidget *parent,
 	{
 		dialog = gtk_message_dialog_new (
 				parent ? GTK_WINDOW(parent) : NULL,
-				GTK_DIALOG_DESTROY_WITH_PARENT,
+				GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
 				GTK_MESSAGE_ERROR,
 				GTK_BUTTONS_CLOSE,
 				_("Cannot overwrite existing file “%s”"), display_name);
@@ -301,7 +299,7 @@ ephy_gui_help (GtkWidget *parent,
 		GtkWidget *dialog;
 
 		dialog = gtk_message_dialog_new (GTK_WINDOW (parent),
-						 GTK_DIALOG_DESTROY_WITH_PARENT,
+						 GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
 						 GTK_MESSAGE_ERROR,
 						 GTK_BUTTONS_OK,
 						 _("Could not display help: %s"),
@@ -392,8 +390,14 @@ ephy_gui_window_update_user_time (GtkWidget *window,
 	if (user_time != 0)
 	{
 		gtk_widget_realize (window);
-		gdk_x11_window_set_user_time (gtk_widget_get_window (window),
-					      user_time);
+
+#ifdef GDK_WINDOWING_X11
+		if (GDK_IS_X11_DISPLAY (gdk_display_get_default ()))
+		{
+			gdk_x11_window_set_user_time (gtk_widget_get_window (window),
+						      user_time);
+		}
+#endif
 	}
 
 }
