@@ -30,6 +30,7 @@
 #include "ephy-embed-shell.h"
 #include "ephy-embed-utils.h"
 #include "ephy-embed.h"
+#include "ephy-encoding-dialog.h"
 #include "ephy-favicon-helpers.h"
 #include "ephy-file-chooser.h"
 #include "ephy-file-helpers.h"
@@ -46,7 +47,6 @@
 #include "ephy-shell.h"
 #include "ephy-string.h"
 #include "ephy-web-app-utils.h"
-#include "ephy-web-dom-utils.h"
 #include "ephy-zoom.h"
 
 #include <gio/gio.h>
@@ -616,7 +616,7 @@ static char *
 get_special_case_application_title_for_host (const char *host)
 {
 	char *title = NULL;
-	int i;
+	guint i;
 
 	for (i = 0; i < G_N_ELEMENTS (sites) && title == NULL; i++)
 	{
@@ -1203,7 +1203,7 @@ view_source_embedded (const char *uri, EphyEmbed *embed)
 static void
 save_temp_source_close_cb (GOutputStream *ostream, GAsyncResult *result, gpointer data)
 {
-	char *uri;
+	const char *uri;
 	GFile *file;
 	GError *error = NULL;
 
@@ -1215,14 +1215,13 @@ save_temp_source_close_cb (GOutputStream *ostream, GAsyncResult *result, gpointe
 		return;
 	}
 
-	uri = (char*)g_object_get_data (G_OBJECT (ostream), "ephy-save-temp-source-uri");
+	uri = (const char*)g_object_get_data (G_OBJECT (ostream), "ephy-save-temp-source-uri");
 
 	file = g_file_new_for_uri (uri);
 
 	if (!ephy_file_launch_handler ("text/plain", file, gtk_get_current_event_time ()))
 	{
 		/* Fallback to view the source inside the browser */
-		const char *uri;
 		EphyEmbed *embed;
 
 		uri = (const char*) g_object_get_data (G_OBJECT (ostream),
@@ -1256,7 +1255,7 @@ save_temp_source_write_cb (GOutputStream *ostream, GAsyncResult *result, GString
 		return;
 	}
 
-	if (written == data->len)
+	if (written == (gint)data->len)
 	{
 		g_string_free (data, TRUE);
 
@@ -1692,3 +1691,14 @@ window_cmd_browse_with_caret (GtkAction *action,
 	g_settings_set_boolean (EPHY_SETTINGS_MAIN,
 				EPHY_PREFS_ENABLE_CARET_BROWSING, active);
 }
+
+void
+window_cmd_view_encoding (GtkAction *action,
+                          EphyWindow *window)
+{
+	EphyEncodingDialog *dialog;
+
+	dialog = ephy_encoding_dialog_new (window);
+	gtk_window_set_transient_for (GTK_WINDOW (dialog), GTK_WINDOW (window));
+	gtk_dialog_run (GTK_DIALOG (dialog));
+}
