@@ -17,9 +17,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with Epiphany; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor,
- * Boston, MA  02110-1301  USA
+ * along with Epiphany.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "config.h"
@@ -88,7 +86,7 @@ fixture_setup (Fixture *fixture, gconstpointer data)
   dest_file = g_build_filename (ephy_file_tmp_dir (), tmp_filename, NULL);
 
   fixture->source = get_uri_for_path ("/default");
-  fixture->download = ephy_download_new_for_uri (fixture->source, NULL);
+  fixture->download = ephy_download_new_for_uri (fixture->source);
   fixture->destination = g_filename_to_uri (dest_file, NULL, NULL);
   fixture->loop = g_main_loop_new (NULL, TRUE);
 
@@ -177,6 +175,7 @@ main (int argc, char *argv[])
   }
 
   _ephy_shell_create_instance (EPHY_EMBED_SHELL_MODE_TEST);
+  g_application_register (G_APPLICATION (ephy_shell_get_default ()), NULL, NULL);
 
   server = soup_server_new (NULL, NULL);
   soup_server_listen_local (server, 0,
