@@ -15,9 +15,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with Epiphany; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor,
- * Boston, MA  02110-1301  USA
+ * along with Epiphany.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "config.h"
@@ -31,7 +29,7 @@
 static EphySQLiteConnection *
 ensure_empty_database (const char* filename)
 {
-  EphySQLiteConnection *connection = ephy_sqlite_connection_new (EPHY_SQLITE_CONNECTION_MODE_READWRITE);
+  EphySQLiteConnection *connection = ephy_sqlite_connection_new ();
   GError *error = NULL;
 
   if (g_file_test (filename, G_FILE_TEST_IS_REGULAR))
