@@ -137,7 +137,7 @@ static const URLTest test_load_url[] = {
 static void
 test_ephy_web_view_load_url (void)
 {
-  int i;
+  guint i;
 
   for (i = 0; i < G_N_ELEMENTS (test_load_url); i++) {
     URLTest test;
@@ -207,7 +207,7 @@ test_ephy_web_view_non_search_regex (void)
 {
   GRegex *regex_non_search, *regex_domain;
   GError *error = NULL;
-  int i;
+  guint i;
 
   regex_non_search = g_regex_new (EPHY_WEB_VIEW_NON_SEARCH_REGEX,
                                   0, G_REGEX_MATCH_NOTEMPTY, &error);
@@ -245,8 +245,8 @@ test_ephy_web_view_non_search_regex (void)
 }
 
 typedef struct {
-  char *url;
-  char *expected;
+  const char *url;
+  const char *expected;
 } normalize_or_autosearch_t;
 
 normalize_or_autosearch_t normalize_or_autosearch_test_ddg[] = {
@@ -278,7 +278,8 @@ verify_normalize_or_autosearch_urls (EphyWebView *view,
   int i;
 
   for (i = 0; i < n_tests; i++) {
-    char *url, *result;
+    const char *url;
+    char *result;
 
     url = test[i].url;
 
